@@ -2,7 +2,7 @@
 #
 #    dgs.R
 #
-#    $Revision: 1.6 $	$Date: 2013/04/25 06:37:43 $
+#    $Revision: 1.7 $	$Date: 2014/10/24 00:22:30 $
 #
 #    Diggle-Gates-Stibbard process
 #
@@ -35,8 +35,7 @@ DiggleGatesStibbard <- local({
             ytarget  = as.double(Ysort$y),
             idtarget = as.integer(idYsort),
             rrho     = as.double(rho),
-            values   = as.double(double(nX)),
-            PACKAGE  = "spatstat")
+            values   = as.double(double(nX)))
     answer <- integer(nX)
     answer[oX] <- out$values
     return(answer)
