@@ -2,7 +2,7 @@
 #
 #    lennard.R
 #
-#    $Revision: 1.17 $	$Date: 2012/01/18 10:56:30 $
+#    $Revision: 1.18 $	$Date: 2014/10/24 00:22:30 $
 #
 #    Lennard-Jones potential
 #
@@ -49,7 +49,7 @@ LennardJones <- local({
              # not enough points
              return(self)
            }
-           s0 <- min(nndist(X))
+           s0 <- minnndist(X)
            if(s0 == 0) {
              warning(paste("Pattern contains duplicated points:",
                            "impossible under Lennard-Jones model"))
