@@ -6,7 +6,7 @@
 #  generic functions
 #  and methods for owin, psp, ppp
 #
-#  $Revision: 1.25 $   $Date: 2013/12/15 11:32:12 $
+#  $Revision: 1.26 $   $Date: 2014/09/27 09:45:44 $
 #
 
 # ............ generic  ............................
@@ -75,7 +75,7 @@ erosion.owin <-
     # compute polygonal region using polyclip package
     pnew <- polyclip::polyoffset(w$bdry, -r, jointype="round")
     # ensure correct polarity
-    totarea <- sum(unlist(lapply(pnew, area.xypolygon)))
+    totarea <- sum(unlist(lapply(pnew, Area.xypolygon)))
     if(totarea < 0)
       pnew <- lapply(pnew, reverse.xypolygon)
     if(shrink.frame) {
@@ -138,7 +138,7 @@ dilation.owin <-
   }
   
   # bounding frame
-  bb <- if(tight) bounding.box(w) else as.rectangle(w)
+  bb <- if(tight) boundingbox(w) else as.rectangle(w)
   newbox <- grow.rectangle(bb, r)
 
   # compute dilation
@@ -154,7 +154,7 @@ dilation.owin <-
     # compute polygonal region using polyclip package
     pnew <- polyclip::polyoffset(w$bdry, r, jointype="round")
     # ensure correct polarity
-    totarea <- sum(unlist(lapply(pnew, area.xypolygon)))
+    totarea <- sum(unlist(lapply(pnew, Area.xypolygon)))
     if(totarea < 0)
       pnew <- lapply(pnew, reverse.xypolygon)
     # determine bounding frame, convert to owin
@@ -218,7 +218,7 @@ dilation.psp <- function(w, r, ..., polygonal=TRUE, tight=TRUE) {
     return(emptywindow(as.owin(w)))
   
   # bounding frame
-  bb <- if(tight) bounding.box(x) else as.rectangle(x)
+  bb <- if(tight) boundingbox(x) else as.rectangle(x)
   newbox <- grow.rectangle(bb, r)
   
   # compute dilation
@@ -265,9 +265,9 @@ dilation.psp <- function(w, r, ..., polygonal=TRUE, tight=TRUE) {
                                       y=ends[i, c("y0","y1")])
     # call
     pnew <- polyclip::polylineoffset(plines, r,
-                                     jointype="round", endtype="round")
+                                     jointype="round", endtype="openround")
     # ensure correct polarity
-    totarea <- sum(unlist(lapply(pnew, area.xypolygon)))
+    totarea <- sum(unlist(lapply(pnew, Area.xypolygon)))
     if(totarea < 0)
       pnew <- lapply(pnew, reverse.xypolygon)
     # convert to owin object
@@ -312,7 +312,7 @@ dilation.ppp <- function(w, r, ..., polygonal=TRUE, tight=TRUE) {
     return(emptywindow(as.owin(w)))
   
   # bounding frame
-  bb <- if(tight) bounding.box(x) else as.rectangle(x)
+  bb <- if(tight) boundingbox(x) else as.rectangle(x)
     newbox <- grow.rectangle(bb, r)
 
   # compute dilation
