@@ -1,7 +1,7 @@
 #
 # pairdistlpp.R
 #
-#  $Revision: 1.9 $ $Date: 2012/10/13 02:25:43 $
+#  $Revision: 1.10 $ $Date: 2014/10/24 00:22:30 $
 #
 #
 #  pairdist.lpp
@@ -83,8 +83,7 @@ pairdist.lpp <- function(X, ..., method="C") {
              to = as.integer(to0),
              dpath = as.double(dpath),
              segmap = as.integer(segmap),
-             answer = as.double(pairdistmat),
-             PACKAGE="spatstat")
+             answer = as.double(pairdistmat))
     pairdistmat <- matrix(zz$answer, n, n)
   }
   return(pairdistmat)
