@@ -1,14 +1,13 @@
 #
 #   plot.im.R
 #
-#  $Revision: 1.96 $   $Date: 2014/08/09 10:34:49 $
+#  $Revision: 1.103 $   $Date: 2014/10/17 10:21:42 $
 #
 #  Plotting code for pixel images
 #
 #  plot.im
 #  image.im
 #  contour.im
-#  persp.im
 #
 ###########################################################################
 
@@ -174,50 +173,30 @@ plot.im <- local({
     imagebreaks <- NULL
     ribbonvalues <- ribbonbreaks <- NULL
 
-    ## predetermined colour map?
-    ## (i.e. mapping from values to colours)
-    colmap <- if(valuesAreColours) colourmap(col=col, inputs=col) else
-              if(inherits(col, "colourmap")) col else NULL
-
-    ## colour map determined by a function?
-    colfun <- NULL
-    if(is.null(colmap) && (!col.given || is.function(col))) {
-      colfun <- if(is.function(col)) col else spatstat.options("image.colfun")
-      colargnames <- names(formals(colfun))
-      ## colfun could be a function(n) that generates n colours,
-      ## or a function(...) that generates a colour map.
-      ## If the latter, convert it to a 'colmap'
-      if("range" %in% colargnames && xtype %in% c("real", "integer")) {
-        # continuous 
-        vrange <- range(range(x, finite=TRUE), zlim)
-        cvals <- try(do.call.matched(colfun,
-                                     append(list(range=vrange), colargs)),
-                     silent=TRUE)
-        if(!inherits(cvals, "try-error")) {
-          colmap <- if(inherits(cvals, "colourmap")) cvals else
-            if(is.character(cvals)) colourmap(cvals, range=vrange) else NULL
-        }
-        if(!is.null(colmap)) colfun <- NULL
-      } else if("inputs" %in% colargnames && xtype != "real") {
-        # discrete
-        vpossible <- switch(xtype,
-                            logical = c(FALSE, TRUE),
-                            factor = levels(x),
-                            unique(as.matrix(x)))
-        if(!is.null(vpossible) && length(vpossible) < 256) {
-          cvals <- try(do.call.matched(colfun,
-                                       append(list(inputs=vpossible), colargs)),
-                       silent=TRUE)
-          if(!inherits(cvals, "try-error")) {
-            colmap <- if(inherits(cvals, "colourmap")) cvals else
-            if(is.character(cvals)) colourmap(cvals, inputs=vpossible) else NULL
-          }
-        if(!is.null(colmap)) colfun <- NULL
-        }
-      } else if(colargnames[1] != "n")
-        stop("Unrecognised syntax for colour function")
+    ## NOW DETERMINE THE COLOUR MAP
+    colfun <- colmap <- NULL
+    if(valuesAreColours) {
+      ## pixel values are colours; set of colours was determined earlier
+      colmap <- colourmap(col=col, inputs=col)
+    } else if(!col.given) {
+      ## no colour information given: use default
+      colfun <- spatstat.options("image.colfun")
+    } else if(inherits(col, "colourmap")) {
+      ## Bob's your uncle
+      colmap <- col
+    } else if(is.function(col)) {
+      ## Some kind of function determining a colour map
+      if(names(formals(col))[1] == "n") {
+        ## function(n) -> colour values
+        colfun <- col
+      } else {
+        ## colour map determined by a rule (e.g. 'beachcolours')
+        colmap <- invokeColourmapRule(col, x, zlim=zlim, colargs=colargs)
+        if(is.null(colmap))
+          stop("Unrecognised syntax for colour function")
+      }
     }
-       
+
     switch(xtype,
            real    = {
              vrange <- range(x, finite=TRUE)
@@ -624,136 +603,52 @@ plot.im <- local({
   PlotIm
 })
 
-
+invokeColourmapRule <- function(colfun, x, ..., zlim=NULL, colargs=list()) {
+  ## utility for handling special functions that generate colour maps
+  ## either 
+  ##        function(... range) -> colourmap
+  ##        function(... inputs) -> colourmap
+  stopifnot(is.im(x))
+  stopifnot(is.function(colfun))
+  colargnames <- names(formals(colfun))
+  ## Convert it to a 'colourmap'
+  colmap <- NULL
+  xtype <- x$type
+  if(xtype %in% c("real", "integer") && "range" %in% colargnames) {
+    ## function(range) -> colourmap
+    vrange <- range(range(x, finite=TRUE), zlim)
+    cvals <- try(do.call.matched(colfun,
+                                 append(list(range=vrange), colargs)),
+                 silent=TRUE)
+    if(!inherits(cvals, "try-error")) {
+      colmap <- if(inherits(cvals, "colourmap")) cvals else
+      if(is.character(cvals)) colourmap(cvals, range=vrange) else NULL
+    }
+  } else if(xtype != "real" && "inputs" %in% colargnames) {
+    ## function(inputs) -> colourmap
+    vpossible <- switch(xtype,
+                        logical = c(FALSE, TRUE),
+                        factor = levels(x),
+                        unique(as.matrix(x)))
+    if(!is.null(vpossible) && length(vpossible) < 256) {
+      cvals <- try(do.call.matched(colfun,
+                                   append(list(inputs=vpossible),
+                                          colargs)),
+                   silent=TRUE)
+      if(!inherits(cvals, "try-error")) {
+        colmap <- if(inherits(cvals, "colourmap")) cvals else
+        if(is.character(cvals))
+          colourmap(cvals, inputs=vpossible) else NULL
+      }
+    }
+  }
+  return(colmap)
+}
 
 ########################################################################
 
 image.im <- plot.im
 
-########################################################################
-
-persp.im <- function(x, ..., colmap=NULL, colin=x, apron=FALSE) {
-  xname <- deparse(substitute(x))
-  xinfo <- summary(x)
-  if(xinfo$type == "factor")
-    stop("Perspective plot is inappropriate for factor-valued image")
-  ## check whether 'col' was specified when 'colmap' was intended
-  Col <- list(...)$col
-  if(is.null(colmap) && !is.null(Col) && !is.matrix(Col) && length(Col) != 1)
-    warning("Argument col is not a matrix. Did you mean colmap?")
-  if(!missing(colin)) {
-    ## separate image to determine colours
-    verifyclass(colin, "im")
-    if(!compatible(colin, x)) {
-      ## resample 'colin' onto grid of 'x'
-      colin <- as.im(colin, W=x)
-    }
-    if(is.null(colmap))
-      colmap <- spatstat.options("image.colfun")(128)
-  }
-  pop <- spatstat.options("par.persp")
-  # colour map?
-  if(is.null(colmap)) {
-    colinfo <- list(col=NULL)
-  } else if(inherits(colmap, "colourmap")) {
-    # colour map object
-    # apply colour function to image data
-    colval <- eval.im(colmap(colin))
-    colval <- t(as.matrix(colval))
-    # strip one row and column for input to persp.default
-    colval <- colval[-1, -1]
-    # replace NA by arbitrary value
-    isna <- is.na(colval)
-    if(any(isna)) {
-      stuff <- attr(colmap, "stuff")
-      colvalues <- stuff$outputs
-      colval[isna] <- colvalues[1]
-    }
-    # pass colour matrix (and suppress lines)
-    colinfo <- list(col=colval, border=NA)
-  } else {
-    # interpret 'colmap' as colour map
-    if(is.list(colmap) && all(c("breaks", "col") %in% names(colmap))) {
-      breaks <- colmap$breaks
-      colvalues <- colmap$col
-    } else if(is.vector(colmap)) {
-      colvalues <- colmap
-      breaks <- quantile(colin, seq(from=0,to=1,length.out=length(colvalues)+1))
-      if(!all(ok <- !duplicated(breaks))) {
-        breaks <- breaks[ok]
-        colvalues <- colvalues[ok[-1]]
-      }
-    } else warning("Unrecognised format for colour map")
-    # apply colour map to image values
-    colid <- cut.im(colin, breaks=breaks, include.lowest=TRUE)
-    colval <- eval.im(colvalues[unclass(colid)])
-    colval <- t(as.matrix(colval))
-    nr <- nrow(colval)
-    nc <- ncol(colval)
-    # strip one row and column for input to persp.default
-    colval <- colval[-1, -1]
-    colval[is.na(colval)] <- colvalues[1]
-    # pass colour matrix (and suppress lines)
-    colinfo <- list(col=colval, border=NA)
-  }
-
-  if(apron) {
-    ## add an 'apron'
-    minx <- min(x)
-    x <- na.handle.im(x, na.replace=minx)
-    x <- padimage(x, minx)
-    xinfo <- summary(x)
-    if(is.matrix(colval <- colinfo$col)) {
-      colval <- matrix(col2hex(colval), nrow(colval), ncol(colval))
-      grijs <- col2hex("lightgrey")
-      colval <- cbind(grijs, rbind(grijs, colval, grijs), grijs)
-      colinfo$col <- colval
-    }
-  }
-
-  if(spatstat.options("monochrome"))
-    colinfo$col <- to.grey(colinfo$col)
-  
-  # get reasonable z scale while fixing x:y aspect ratio
-  if(xinfo$type %in% c("integer", "real")) {
-    zrange <- xinfo$range
-    if(diff(zrange) > 0) {
-      xbox <- as.rectangle(x)
-      zscale <- 0.5 * mean(diff(xbox$xrange), diff(xbox$yrange))/diff(zrange)
-      zlim <- zrange
-    } else {
-      zscale <- NULL
-      zlim <- c(0,2) * xinfo$mean
-    }
-  } else 
-    zscale <- zlim <- NULL
-
-  yargh <- resolve.defaults(list(x=x$xcol, y=x$yrow, z=t(x$v)),
-                            list(...),
-                            pop,
-                            colinfo,
-                            list(xlab="x", ylab="y", zlab=xname),
-                            list(scale=FALSE, expand=zscale,
-                                 zlim=zlim),
-                            list(main=xname),
-                            .StripNull=TRUE)
-
-  jawab <- do.call.matched("persp", yargh, 
-                           funargs=.Spatstat.persp.args)
-
-  attr(jawab, "expand") <- yargh$expand
-  return(invisible(jawab))
-}
-
-.Spatstat.persp.args <- list("x", "y", "z",
-                             "xlim", "ylim", "zlim",
-                             "xlab", "ylab", "zlab",
-                             "main", "sub",
-                             "theta", "phi", "r", "d", "scale",
-                             "expand", "col", "border",
-                             "ltheta", "lphi", "shade", "box",
-                             "axes", "nticks", "ticktype")
-
 ######################################################################
 
 contour.im <- function (x, ..., main, axes=FALSE, add=FALSE,
@@ -803,4 +698,3 @@ contour.im <- function (x, ..., main, axes=FALSE, add=FALSE,
   return(invisible(z))
 }
 
-
