@@ -3,11 +3,11 @@
 #
 #   random (re)labelling
 #
-#   $Revision: 1.5 $   $Date: 2010/11/21 04:24:29 $
+#   $Revision: 1.7 $   $Date: 2013/02/27 01:01:20 $
 #
 #
 rlabel <- function(X, labels=marks(X), permute=TRUE) {
-  verifyclass(X, "ppp")
+  stopifnot(is.ppp(X) || is.lpp(X) || is.pp3(X) || is.ppx(X))
   if(is.null(labels))
     stop("labels not given and marks not present")
   npts <- npoints(X)
@@ -16,7 +16,7 @@ rlabel <- function(X, labels=marks(X), permute=TRUE) {
     if(permute && (nlabels != npts))
       stop("length of labels vector does not match number of points")
     Y <- X %mark% sample(labels, npts, replace=!permute)
-  } else if(is.data.frame(labels)) {
+  } else if(is.data.frame(labels) || is.hyperframe(labels)) {
     nlabels <- nrow(labels)
     if(permute && (nlabels != npts))
       stop("number of rows of data frame does not match number of points")      
