@@ -3,7 +3,7 @@
 #
 #	A class 'owin' to define the "observation window"
 #
-#	$Revision: 4.152 $	$Date: 2014/08/04 09:35:50 $
+#	$Revision: 4.155 $	$Date: 2014/10/03 15:12:44 $
 #
 #
 #	A window may be either
@@ -151,7 +151,7 @@ owin <- function(xrange=c(0,1), yrange=c(0,1),
       # single boundary polygon
       bdry <- list(poly)
       if(check || calculate) {
-        w.area <- area.xypolygon(poly)
+        w.area <- Area.xypolygon(poly)
         if(w.area < 0)
           stop(paste("Area of polygon is negative -",
                      "maybe traversed in wrong direction?"))
@@ -160,7 +160,7 @@ owin <- function(xrange=c(0,1), yrange=c(0,1),
       # multiple boundary polygons
       bdry <- poly
       if(check || calculate) {
-        w.area <- unlist(lapply(poly, area.xypolygon))
+        w.area <- unlist(lapply(poly, Area.xypolygon))
         if(sum(w.area) < 0)
           stop(paste("Area of window is negative;\n",
                      "check that all polygons were traversed",
@@ -208,21 +208,33 @@ owin <- function(xrange=c(0,1), yrange=c(0,1),
       }
     }
     if(check && fix) {
-      ## repair polygon data by invoking polyclip
-      ##        to intersect polygon with bounding rectangle
-      ##        (Streamlined version of intersect.owin)
-      ww <- lapply(bdry, reverse.xypolygon)
-      rr <- list(list(x=xrange[c(1,2,2,1)], y=yrange[c(2,2,1,1)]))
-      bb <- polyclip::polyclip(ww, rr, "intersection",
-                               fillA="nonzero", fillB="nonzero")
-      ## ensure correct polarity
-      totarea <- sum(unlist(lapply(bb, area.xypolygon)))
-      if(totarea < 0)
-        bb <- lapply(bb, reverse.xypolygon)
-      w$bdry <- bb
+      if(length(bdry) == 1 &&
+         length(bx <- bdry[[1]]$x) == 4 &&
+         length(unique(bx)) == 2 &&
+         length(unique(bdry[[1]]$y)) == 2) {
+        ## it's really a rectangle
+        if(Area.xypolygon(bdry[[1]]) < 0)
+          w$bdry <- lapply(bdry, reverse.xypolygon)
+      } else {
+        ## repair polygon data by invoking polyclip
+        ##        to intersect polygon with larger-than-bounding rectangle
+        ##        (Streamlined version of intersect.owin)
+        ww <- lapply(bdry, reverse.xypolygon)
+        xrplus <- mean(xrange) + c(-1,1) * diff(xrange)
+        yrplus <- mean(yrange) + c(-1,1) * diff(yrange)
+        bignum <- (.Machine$integer.max^2)/2
+        epsclip <- max(diff(xrange), diff(yrange))/bignum
+        rr <- list(list(x=xrplus[c(1,2,2,1)], y=yrplus[c(2,2,1,1)]))
+        bb <- polyclip::polyclip(ww, rr, "intersection",
+                                 fillA="nonzero", fillB="nonzero", eps=epsclip)
+        ## ensure correct polarity
+        totarea <- sum(unlist(lapply(bb, Area.xypolygon)))
+        if(totarea < 0)
+          bb <- lapply(bb, reverse.xypolygon)
+        w$bdry <- bb
+      }
     }
     return(w)
-    
   } else if(mask.given) {
     ######### digital mask #####################
     
@@ -763,7 +775,7 @@ complement.owin <- function(w, frame=as.rectangle(w)) {
            # bounding box, in anticlockwise order
            box <- list(x=w$xrange[c(1,2,2,1)],
                        y=w$yrange[c(1,1,2,2)])
-           boxarea <- area.xypolygon(box)
+           boxarea <- Area.xypolygon(box)
                  
            # first check whether one of the current boundary polygons
            # is the bounding box itself (with + sign)
@@ -771,9 +783,9 @@ complement.owin <- function(w, frame=as.rectangle(w)) {
              is.box <- rep.int(FALSE, length(bdry))
            else {
              nvert <- unlist(lapply(bdry, function(a) { length(a$x) }))
-             area <- unlist(lapply(bdry, area.xypolygon))
+             areas <- unlist(lapply(bdry, Area.xypolygon))
              boxarea.mineps <- boxarea * (0.99999)
-             is.box <- (nvert == 4 & area >= boxarea.mineps)
+             is.box <- (nvert == 4 & areas >= boxarea.mineps)
              if(sum(is.box) > 1)
                stop("Internal error: multiple copies of bounding box")
              if(all(is.box)) {
@@ -907,7 +919,7 @@ summary.owin <- function(object, ...) {
   result <- list(xrange=object$xrange,
                  yrange=object$yrange,
                  type=object$type,
-                 area=area.owin(object),
+                 area=area(object),
                  units=unitname(object))
   switch(object$type,
          rectangle={
@@ -918,10 +930,10 @@ summary.owin <- function(object, ...) {
            if(npoly == 0) {
              result$areas <- result$nvertices <- numeric(0)
            } else if(npoly == 1) {
-             result$areas <- area.xypolygon(poly[[1]])
+             result$areas <- Area.xypolygon(poly[[1]])
              result$nvertices <- length(poly[[1]]$x)
            } else {
-             result$areas <- unlist(lapply(poly, area.xypolygon))
+             result$areas <- unlist(lapply(poly, Area.xypolygon))
              result$nvertices <- unlist(lapply(poly,
                                                function(a) {length(a$x)}))
            }
